Coverage for /Users/Dave/git_repos/_packages_/python/fundamentals/fundamentals/renderer/__init__.py: 100%

# Coverage for /Users/Dave/git_repos/_packages_/python/fundamentals/fundamentals/renderer/__init__.py : 100%

## 2 statements 2 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1"""

2*Render python objects as various list and markup formats *

3"""

4 from __future__ import absolute_import

5 from .list_of_dictionaries import list_of_dictionaries